@@ -3,13 +3,14 @@
 #' @param ci Confidence Interval (CI) level. Default to 0.95 (95\%).
 #' @param dof Degrees of Freedom. If not specified, for \code{ci_wald()}, defaults to model's residual degrees of freedom (i.e. \code{n-k}, where \code{n} is the number of observations and \code{k} is the number of parameters). For \code{p_value_wald()}, defaults to \code{Inf}.
 #' @inheritParams model_simulate
+#' @inheritParams standard_error
 #'
 #' @importFrom stats qt coef
 #' @export
-ci_wald <- function(model, ci = .95, dof = NULL, component = c("all", "conditional", "zi", "zero_inflated")) {
+ci_wald <- function(model, ci = .95, dof = NULL, component = c("all", "conditional", "zi", "zero_inflated"), robust = FALSE, ...) {
   component <- match.arg(component)
   out <- lapply(ci, function(i) {
-    .ci_wald(model = model, ci = i, dof = dof, component = component)
+    .ci_wald(model = model, ci = i, dof = dof, component = component, robust = robust, ...)
   })
   out <- do.call(rbind, out)
   row.names(out) <- NULL
@@ -20,11 +21,15 @@ ci_wald <- function(model, ci = .95, dof = NULL, component = c("all", "condition
 #' @importFrom insight get_parameters n_obs
 #' @importFrom stats qt
 #' @keywords internal
-.ci_wald <- function(model, ci, dof, component) {
+.ci_wald <- function(model, ci, dof, component, robust = FALSE, ...) {
   params <- insight::get_parameters(model, effects = "fixed", component = component)
-  ## TODO change to "$Estimate" once fixed in insight
-  estimates <- params[[2]]
-  stderror <- standard_error(model, component = component)
+  estimates <- params$Estimate
+
+  stderror <- if (isTRUE(robust)) {
+    standard_error_robust(model, ...)
+  } else {
+    standard_error(model, component = component)
+  }
 
   # filter non-matching parameters
   stderror <- stderror[1:nrow(params), ]
@@ -32,13 +37,7 @@ ci_wald <- function(model, ci = .95, dof = NULL, component = c("all", "condition
 
   if (is.null(dof)) {
     # residual df
-    dof <- tryCatch({
-      insight::n_obs(model) - nrow(params)
-    },
-    error = function(e) {
-      Inf
-    }
-    )
+    dof <- degrees_of_freedom(model, method = "any")
     # make sure we have a value for degrees of freedom
     if (is.null(dof) || length(dof) == 0) dof <- Inf
   }
@@ -52,12 +51,9 @@ ci_wald <- function(model, ci = .95, dof = NULL, component = c("all", "condition
 
   out <- as.data.frame(out)
   out$CI <- ci * 100
-  ## TODO change to "$Parameter" once fixed in insight
-  out$Parameter <- params[[1]]
+  out$Parameter <- params$Parameter
 
   out <- out[c("Parameter", "CI", "CI_low", "CI_high")]
-  ## TODO remove once fixed in insight
-  if ("component" %in% names(params)) out$Component <- params$component
   if ("Component" %in% names(params)) out$Component <- params$Component
 
   out
