@@ -3,7 +3,7 @@
 #' The Wald-test approximation treats t-values as Wald z. Since the t distribution converges to the z distribution as degrees of freedom increase, this is like assuming infinite degrees of freedom. While this is unambiguously anti-conservative, this approximation appears as reasonable for reasonable sample sizes (Barr et al., 2013). That is, if we take the p-value to measure the probability of a false positive, this approximation produces a higher false positive rate than the nominal 5\% at p = 0.05.
 #'
 #' @param model A statistical model.
-#' @param ... Currently not used.
+#' @param ... Arguments passed down to \code{standard_error_robust()} when confidence intervals or p-values based on robust standard errors should be computed.
 #'
 #' @examples
 #' \donttest{
@@ -48,7 +48,7 @@ p_value_wald.merMod <- function(model, dof = Inf, ...) {
   }
 
   .data_frame(
-    Parameter = coef_names,
+    Parameter = .remove_backticks_from_string(coef_names),
     p = unname(p)
   )
 }
