@@ -42,21 +42,25 @@
 parameters_type <- function(model, ...) {
 
   # Get info
-  params <- .data_frame(
-    Parameter = c(
-      insight::find_parameters(model, effects = "fixed", flatten = TRUE)
-    )
+  params <- data.frame(
+    Parameter = insight::find_parameters(model, effects = "fixed", flatten = TRUE),
+    stringsAsFactors = FALSE
   )
 
+  # Special case
   if (inherits(model, "polr")) {
     params$Parameter <- gsub("Intercept: ", "", params$Parameter, fixed = TRUE)
   }
 
-  ## TODO can we get rid of the count_ / zero_ prefix here?
 
-  # if (inherits(model, c("zeroinfl", "hurdle", "zerocount"))) {
-  #   params$Parameter <- gsub("^(count_|zero_)", "", params$Parameter)
-  # }
+  # Remove "as.factor()", "log()" etc. from parameter names but save original parameter before
+  original_parameter <- params$Parameter
+  params$Parameter <- .clean_parameter_names(params$Parameter, full = TRUE)
+
+  ## TODO can we get rid of the count_ / zero_ prefix here?
+  if (inherits(model, c("zeroinfl", "hurdle", "zerocount"))) {
+    params$Parameter <- gsub("^(count_|zero_)", "", params$Parameter)
+  }
 
 
   data <- insight::get_data(model)
@@ -79,11 +83,15 @@ parameters_type <- function(model, ...) {
   }
   for (i in unique(out$Secondary_Parameter)) {
     if (!is.na(i) && i %in% out$Parameter) {
-      out[!is.na(out$Secondary_Parameter) & out$Secondary_Parameter == i, "Secondary_Type"] <- out[!is.na(out$Parameter) & out$Parameter == i, "Type"]
+      .param_type <- out[!is.na(out$Parameter) & out$Parameter == i, "Type"]
+      .param_secondary_type <- out[!is.na(out$Secondary_Parameter) & out$Secondary_Parameter == i, "Secondary_Type"]
+      if (length(.param_type) == length(.param_secondary_type) || length(.param_type) == 1) {
+        out[!is.na(out$Secondary_Parameter) & out$Secondary_Parameter == i, "Secondary_Type"] <- .param_type
+      }
     }
   }
 
-  # Out
+  out$Parameter <- original_parameter
   out
 }
 
@@ -93,7 +101,7 @@ parameters_type <- function(model, ...) {
 .parameters_type_table <- function(names, data, reference) {
   out <- lapply(names, .parameters_type, data = data, reference = reference)
   out <- as.data.frame(do.call(rbind, out), stringsAsFactors = FALSE)
-  names(out) <- c("Type", "Term", "Variable", "Level", "Secondary_Parameter")
+  names(out) <- c("Type", "Link", "Term", "Variable", "Level", "Secondary_Parameter")
   out
 }
 
@@ -113,8 +121,12 @@ parameters_type <- function(model, ...) {
       var <- rev(var)
     }
 
+    # Check if any is factor
+    types <- unlist(lapply(var, function(x, data, reference) .parameters_type_basic(x, data, reference)[1], data = data, reference = reference))
+    link <- ifelse(any("factor" %in% types), "Difference", "Association")
+    # Get type
     main <- .parameters_type_basic(var[1], data, reference)
-    return(c("interaction", main[2], main[3], main[4], var[2]))
+    return(c("interaction", link, main[3], main[4], main[5], var[2]))
   } else {
     .parameters_type_basic(name, data, reference)
   }
@@ -127,21 +139,30 @@ parameters_type <- function(model, ...) {
 #' @keywords internal
 .parameters_type_basic <- function(name, data, reference) {
   if (is.na(name)) {
-    return(c(NA, NA, NA, NA, NA))
+    return(c(NA, NA, NA, NA, NA, NA))
+  }
 
-    # Intercept
-  } else if (name == "(Intercept)" | name == "b_Intercept") {
-    return(c("intercept", "(Intercept)", NA, NA, NA))
+  # parameter type is determined here. for formatting / printing,
+  # refer to ".format_parameter()". Make sure that pattern
+  # processed here are not "cleaned" (i.e. removed) in
+  # ".clean_parameter_names()"
+
+  cleaned_name <- .clean_parameter_names(name, full = TRUE)
+
+  # Intercept
+  if (.in_intercepts(cleaned_name)) {
+    return(c("intercept", "Mean", "(Intercept)", NA, NA, NA))
 
     # Numeric
-  } else if (name %in% reference$numeric) {
-    return(c("numeric", name, name, NA, NA))
+  } else if (cleaned_name %in% reference$numeric) {
+    return(c("numeric", "Association", name, name, NA, NA))
 
     # Factors
-  } else if (name %in% reference$levels) {
-    fac <- reference$levels_parent[match(name, reference$levels)]
+  } else if (cleaned_name %in% reference$levels) {
+    fac <- reference$levels_parent[match(cleaned_name, reference$levels)]
     return(c(
       "factor",
+      "Difference",
       name,
       fac,
       gsub(fac, "", name, fixed = TRUE),
@@ -161,16 +182,42 @@ parameters_type <- function(model, ...) {
     var <- vars[[1]]
     degree <- vars[[2]]
     degree <- substr(vars[[2]], nchar(vars[[2]]), nchar(vars[[2]]))
-    return(c(type, name, var, degree, NA))
+    return(c(type, "Association", name, var, degree, NA))
+
+    # Splines
+  } else if (grepl("(bs|ns|psline|rcs)\\(", name)) {
+    type <- "spline"
+    var <- gsub("(bs|ns|psline|rcs)\\((.*)\\)(\\d)", "\\2", name)
+    if (grepl(",", var, fixed = TRUE)) {
+      var <- substr(var, start = 0, stop = regexpr(",", var, fixed = TRUE) - 1)
+    }
+    degree <- gsub("(bs|ns|psline|rcs)\\((.*)\\)(\\d)", "\\3", name)
+    return(c(type, "Association", name, var, degree, NA))
+
+    # log-transformation
+  } else if (grepl("(log|logb|log1p|log2|log10)\\(", name)) {
+    type <- "logarithm"
+    var <- gsub("(log|logb|log1p|log2|log10)\\((.*)\\)", "\\2", name)
+    if (grepl(",", var, fixed = TRUE)) {
+      var <- substr(var, start = 0, stop = regexpr(",", var, fixed = TRUE) - 1)
+    }
+    return(c(type, "Association", name, var, NA, NA))
+
+    # As Is
+  } else if (grepl("^I\\(", name)) {
+    type <- "asis"
+    var <- gsub("^I\\((.*)\\)", "\\1", name)
+    return(c(type, "Association", name, var, NA, NA))
 
     # Smooth
   } else if (grepl("^s\\(", name)) {
-    return(c("smooth", name, NA, NA, NA))
+    return(c("smooth", "Association", name, NA, NA, NA))
+
     # Smooth
   } else if (grepl("^smooth_", name)) {
-    return(c("smooth", gsub("^smooth_(.*)\\[(.*)\\]", "\\2", name), NA, NA, NA))
+    return(c("smooth", "Association", gsub("^smooth_(.*)\\[(.*)\\]", "\\2", name), NA, NA, NA))
   } else {
-    return(c("unknown", NA, NA, NA, NA))
+    return(c("unknown", NA, NA, NA, NA, NA))
   }
 }
 
@@ -196,3 +243,5 @@ parameters_type <- function(model, ...) {
 
   out
 }
+
+
